Stan Math Library: stan/math/prim/scal/meta/length_mvt.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

length_mvt.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_META_LENGTH_MVT_HPP
2 #define STAN_MATH_PRIM_SCAL_META_LENGTH_MVT_HPP
3
4 #include <stdexcept>
5
6 namespace stan {
7
8 template <typename T>
9 size_t length_mvt(const T& ) {
10 throw std::out_of_range("length_mvt passed to an unrecognized type.");
11 return 1U;
12 }
13
14 }
15 #endif
16
stan
Definition: log_sum_exp.hpp:8
stan::math::out_of_range
void out_of_range(const char *function, const int max, const int index, const char *msg1="", const char *msg2="")
Throw an out_of_range exception with a consistently formatted message.
Definition: out_of_range.hpp:30
stan::length_mvt
size_t length_mvt(const Eigen::Matrix< T, R, C > &)
Definition: length_mvt.hpp:12

[ Stan Home Page ] © 2011–2016, Stan Development Team.